@@ -3,24 +3,19 @@
 #
 
 # Unset all optional variables first to start from a clean state
-unset NONUS             || true
-unset FORCENONUSONCD1   || true
 unset NONFREE           || true
 unset CONTRIB           || true
 unset EXTRANONFREE      || true
 unset LOCAL             || true
 unset LOCALDEBS         || true
-unset SECURED           || true
 unset SECURITY          || true
 unset BOOTDIR           || true
-unset BOOTDISKS         || true
 unset SYMLINK           || true
 unset COPYLINK          || true
 unset MKISOFS           || true
 unset MKISOFS_OPTS      || true
 unset ISOLINUX          || true
 unset EXCLUDE           || true
-unset SRCEXCLUDE        || true
 unset NORECOMMENDS      || true
 unset NOSUGGESTS        || true
 unset DOJIGDO           || true
@@ -29,11 +24,7 @@ unset JIGDOFALLBACKURLS || true
 unset JIGDOINCLUDEURLS  || true
 unset JIGDOSCRIPT       || true
 unset JIGDO_OPTS        || true
-unset DEFBINSIZE        || true
-unset DEFSRCSIZE        || true
-unset FASTSUMS          || true
 unset PUBLISH_URL       || true
-unset PUBLISH_NONUS_URL || true
 unset PUBLISH_PATH      || true
 unset UDEB_INCLUDE      || true
 unset UDEB_EXCLUDE      || true
@@ -42,7 +33,7 @@ unset BASE_EXCLUDE      || true
 unset INSTALLER_CD      || true
 unset MAXCDS            || true
 unset SPLASHPNG         || true
-unset OMIT_MANUAL	    || true
+unset OMIT_MANUAL	 || true
 unset OMIT_RELEASE_NOTES || true
 
 # The debian-cd dir
@@ -53,9 +44,8 @@ export BASEDIR=`pwd`
 export CODENAME=etch
 
 # By default use Debian installer packages from $CODENAME
-if [ ! "$DI_CODENAME" ]
-then
-  export DI_CODENAME=$CODENAME
+if [ -z "$DI_CODENAME" ]; then
+	export DI_CODENAME=$CODENAME
 fi
 
 # If set, controls where the d-i components are downloaded from.
@@ -65,7 +55,7 @@ fi
 #export DI_WWW_HOME=default
 
 # Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="3.1"
+export DEBVERSION="4.0"
 
 # Official or non-official set.
 # NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -74,8 +64,23 @@ export OFFICIAL="Unofficial"
 #export OFFICIAL="Official"
 #export OFFICIAL="Official Beta"
 
-# ... for arch  
-export ARCH=`dpkg --print-architecture`
+# ... for arch
+if [ -z "$ARCHES" ]; then
+	CPU=`dpkg-architecture -qDEB_HOST_DPKG_CPU 2>/dev/null || true`
+	if [ -z "$CPU" ]; then
+		CPU=`dpkg-architecture -qDEB_HOST_ARCH`
+	fi
+	KERNEL=`dpkg-architecture -qDEB_HOST_DPKG_OS 2>/dev/null || true`
+	if [ -z "$KERNEL" ]; then
+		KERNEL=linux
+	fi
+	if [ $KERNEL = linux ] ; then
+		ARCHES=$CPU
+	else
+		ARCHES="$KERNEL-$CPU"
+	fi
+	export ARCHES
+fi
 
 # IMPORTANT : The 4 following paths must be on the same partition/device.
 #	      If they aren't then you must set COPYLINK below to 1. This
@@ -83,25 +88,17 @@ export ARCH=`dpkg --print-architecture`
 #	      images, however. Also, if you are using an NFS partition for
 #	      some part of this, you must use this option.
 # Paths to the mirrors
-export MIRROR=/ftp/debian
-
-# Comment the following line if you don't have/want non-US
-#export NONUS=/ftp/debian-non-US
-
-# And this option will make you 2 copies of CD1 - one with all the
-# non-US packages on it, one with none. Useful if you're likely to
-# need both.
-#export FORCENONUSONCD1=1
+export MIRROR=/mirror/debian
 
 # Path of the temporary directory
-export TDIR=/ftp/tmp
+export TDIR=/mirror/tmp
 
 # Path where the images will be written
-export OUT=/rack/debian-cd
+export OUT=/mirror/debian-cd-test
 
 # Where we keep the temporary apt stuff.
 # This cannot reside on an NFS mount.
-export APTTMP=/ftp/tmp/apt
+export APTTMP=/mirror/tmp/apt
 
 # Do I want to have NONFREE merged in the CD set
 # export NONFREE=1
@@ -123,11 +120,6 @@ export CONTRIB=1
 # containing dists/$CODENAME/local/binary-$ARCH
 # export LOCALDEBS=/home/joey/debian/va/debian
 
-# If you want a <codename>-secured tree with a copy of the signed
-# Release.gpg and files listed by this Release file, then
-# uncomment this line
-# export SECURED=1
-
 # Where to find the security patches.  This directory should be the
 # top directory of a security.debian.org mirror.
 #export SECURITY="$TOPDIR"/debian/debian-security
@@ -156,24 +148,28 @@ export ISOLINUX=1
 
 # uncoment this to make build_all.sh try to build a simple CD image if
 # the proper official CD run does not work
-#ATTEMPT_FALLBACK=yes
+ATTEMPT_FALLBACK=yes
 
-# Set your disk size here in MB. Used in calculating package and
-# source file layouts in build.sh and build_all.sh. Defaults are for
-# CD-R, try ~4600 for DVD-R.
-export DEFBINSIZE=630
-export DEFSRCSIZE=635
+# Set your disk type here. Known types are:
+# BC (businesscard): 650 MiB max (should be limited elsewhere,
+#                    should never fill a CD anyway)
+# NETINST:           650 MiB max (ditto)
+# CD:                standard 74-min CD (650 MiB)
+# CD700:             (semi-)standard 80-min CD (700 MiB)
+# DVD:               standard 4.7 GB DVD
+# CUSTOM:            up to you - specify a size to go with it (in 2K blocks)
+export DISKTYPE=CD
+#export DISKTYPE=CUSTOM
+#export CUSTOMSIZE=XXXX
 
 # We don't want certain packages to take up space on CD1...
-export EXCLUDE="$BASEDIR"/tasks/exclude-$CODENAME
-# ...but they are okay for other CDs (UNEXCLUDEx == may be included on CD >= x)
-export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-$CODENAME
+#export EXCLUDE1="$BASEDIR"/tasks/exclude-$CODENAME
+# ...but they are okay for other CDs (UNEXCLUDEx == may be included
+# on CD x if not already covered)
+#export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-$CODENAME
 # Any packages listed in EXCLUDE but not in any UNEXCLUDE will be
 # excluded completely.
 
-# We also exclude some source packages
-#export SRCEXCLUDE="$BASEDIR"/tasks/exclude-src-$CODENAME
-
 # Set this if the recommended packages should be skipped when adding 
 # package on the CD.  The default is 'false'.
 export NORECOMMENDS=1
@@ -185,18 +181,9 @@ export NORECOMMENDS=1
 # Produce jigdo files:
 # 0/unset = Don't do jigdo at all, produce only the full iso image.
 # 1 = Produce both the iso image and jigdo stuff.
-# 2 = Produce ONLY jigdo stuff by piping mkisofs directly into jigdo-file,
-#     no temporary iso image is created (saves lots of disk space).
-#     NOTE: The no-temp-iso will not work for (at least) alpha and powerpc
-#     since they need the actual .iso to make it bootable. For these archs,
-#     the temp-iso will be generated, but deleted again immediately after the
-#     jigdo stuff is made; needs temporary space as big as the biggest image.
-#export DOJIGDO=2
-#
-# jigdo-file command & options
-# Note: building the cache takes hours, so keep it around for the next run
-#export JIGDOCMD="/usr/local/bin/jigdo-file --cache=$HOME/jigdo-cache.db"
-#
+# 2 = Produce only the jigdo stuff
+export DOJIGDO=1
+
 # HTTP/FTP URL for directory where you intend to make the templates
 # available. You should not need to change this; the default value ""
 # means "template in same dir as the .jigdo file", which is usually
@@ -231,15 +218,10 @@ export JIGDOINCLUDEURLS="http://cdimage.debian.org/debian-cd/debian-servers.jigd
 # data.
 #export JIGDOSCRIPT="myscript"
 
-# If set, use the md5sums from the main archive, rather than calculating
-# them locally
-#export FASTSUMS=1
-
 # A couple of things used only by publish_cds, so it can tweak the
 # jigdo files, and knows where to put the results.
 # You need to run publish_cds manually, it is not run by the Makefile.
 export PUBLISH_URL="http://cdimage.debian.org/jigdo-area"
-export PUBLISH_NONUS_URL="http://non-US.cdimage.debian.org/jigdo-area"
 export PUBLISH_PATH="/home/jigdo-area/"
 
 # Specify files and directories to *exclude* from jigdo processing. These
@@ -257,19 +239,14 @@ export JIGDO_INCLUDE="/pool/"
 # smaller than this will simply be placed straight into the template file.
 export JIGDO_OPTS="-jigdo-min-file-size 0"
 
-for EXCL in $JIGDO_EXCLUDE
-do
-    JIGDO_OPTS="$JIGDO_OPTS -jigdo-exclude $EXCL"
+for EXCL in $JIGDO_EXCLUDE; do
+	JIGDO_OPTS="$JIGDO_OPTS -jigdo-exclude $EXCL"
 done
 
-for INCL in $JIGDO_INCLUDE
-do
-    JIGDO_OPTS="$JIGDO_OPTS -jigdo-force-md5 $INCL"
+for INCL in $JIGDO_INCLUDE; do
+	JIGDO_OPTS="$JIGDO_OPTS -jigdo-force-md5 $INCL"
 done
 
-# Where to find the boot disks
-#export BOOTDISKS=$TOPDIR/ftp/skolelinux/boot-floppies
-
 # File with list of packages to include when fetching modules for the
 # first stage installer (debian-installer). One package per line.
 # Lines starting with '#' are comments.  The package order is
@@ -293,30 +270,85 @@ done
 # INSTALLER_CD=0: nothing special (default)
 # INSTALLER_CD=1: just add debian-installer (use TASK=tasks/debian-installer-$CODENAME)
 # INSTALLER_CD=2: add d-i and base (use TASK=tasks/debian-installer+kernel-$CODENAME)
-#export INSTALLER_CD=0
+#export INSTALLER_CD=2
 
-# Parameters to pass to kernel when the CD boots. Not currently supported
-# for all architectures.
+# Parameters to pass to kernel (or d-i) when the CD boots. Not currently
+# supported for all architectures.
 #export KERNEL_PARAMS="DEBCONF_PRIORITY=critical"
 
 # If set, limits the number of binary CDs to produce.
-#export MAXCDS=1
+export MAXCDS=1
 
 # If set, overrides the boot picture used.
 #export SPLASHPNG="$BASEDIR/data/$CODENAME/splash-img.png"
 
-# Used by build.sh to determine what to build, this is the name of a target
-# in the Makefile. Use bin-official_images to build only binary CDs. The
-# default, official_images, builds everything.
-#IMAGETARGET=official_images
-
 # Set to 1 to save space by omitting the installation manual. 
 # If so the README will link to the manual on the web site.
 #export OMIT_MANUAL=1
 
 # Set to 1 to save space by omitting the release notes
 # If so we will link to them on the web site.
-export OMIT_RELEASE_NOTES=0
+export OMIT_RELEASE_NOTES=1
 
-# Set this to override the defaul location
+# Set this to override the default location
 #export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/$CODENAME"
+
+case "$OFFICIAL" in
+    "Official")
+	export OFFICIAL_VAL=2
+	;;
+    "Official Beta")
+	export OFFICIAL_VAL=1
+	;;
+    *)
+	export OFFICIAL_VAL=0
+	;;
+esac
+
+##################################
+# LOCAL HOOK DEFINITIONS
+##################################
+#
+# Set these to point to scripts/programs to be called at various 
+# points in the debian-cd image-making process. This is the ideal place
+# to customise what's on the CDs, for example to add extra files or
+# modify existing ones. Each will be called with the arguments in order:
+#
+# $TDIR (the temporary dir containing the build tree)
+# $MIRROR (the location of the mirror)
+# $DISKNUM (the image number in the set)
+# $CDDIR (the root of the temp disc tree)
+# $ARCHES (the set of architectures chosen)
+#
+# BE CAREFUL about what you do at each point: in the first couple of 
+# cases, files and directories you're looking to use may not exist yet,
+# you may need to worry about adding entries into md5sum.txt yourself
+# and (in the last couple of cases) if you add any extra files you may
+# end up over-filling the disc. If you *do* need to add files at the end
+# of the process, see RESERVED_BLOCKS_HOOK below. It's strongly
+# recommended to do this kind of customisation up-front if you can, it's
+# much simpler that way!
+
+# The disc_start hook. This will be called near the beginning of the
+# start_new_disc script, just after the directory tree has been created
+# but before any files have been added
+#export DISC_START_HOOK=/bin/true
+
+# The disc_pkg hook. This will be called just after the
+# start_new_disc script has finished, just before make_disc_trees.pl
+# starts to add package files.
+#export DISC_PKG_HOOK=/bin/true
+
+# The reserved_blocks hook; if set, this script should print the
+# number of 2K blocks that need to be reserved for data to be added
+# *after* a disc tree is filled with packages.
+#export RESERVED_BLOCKS_HOOK=/bin/true
+
+# The disc_finish hook. This will be called once a disc image is full,
+# just after the last package rollback but before the last bits of
+# cleanup are done on the temp disc tree
+#export DISC_FINISH_HOOK=/bin/true
+
+# The disc_end hook. This will be called *right* at the end of the
+# image-making process in make_disc_trees.pl.
+#export DISC_END_HOOK=/bin/true
